==> PMCMRplus_1.5.0.tar.gz: PMCMRplus/inst/NEWS.Rd <==
\name{NEWS}
\title{PMCMRplus News}
\encoding{UTF-8}
\section{CHANGES IN PMCMRPLUS VERSION 1.5.0 (2020-09-09)}{
 \subsection{NEW FEATURES}{
  \itemize{
    \item S3 method for class\sQuote{aov} was added
    for \code{tukeyTest}, \code{gamesHowellTest},
    \code{lsdTest}, \code{tamhaneT2Test},
    \code{uryWigginsHochbergTest}, \code{dunnettT3Test},
    \code{snkTest}, \code{scheffeTest}, \code{dunnettTest},
    \code{tamhaneDunnettTest} and \code{welchManyOneTTest}.
    \item Updated concept-tag in Rd files.
  }
 }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.4.4}{
  \subsection{OTHER CHANGES}{
    \itemize{
      \item The examples in \code{kruskalTest}, \code{adKSampleTest}
      and \code{bwsKSampleTest} were
      changed for compatibility with
      the upcoming \sQuote{stringsAsFactors = FALSE} default in R (4.0.0).
      }
    }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.4.3}{
  \subsection{OTHER CHANGES}{
    \itemize{
     \item The names for the \sQuote{method} were corrected for \code{adAllPairsTest} and \code{bwsAllPairsTest}.
     \item The example in \code{adKSampleTest} was corrected.
     }
   }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.4.2}{
 \subsection{NEW FEATURES}{
    \itemize{
      \item The S3 method for class \sQuote{formula} was added
      for \code{frdAllPairsNemenyiTest}.
      }
}
 \subsection{OTHER CHANGES}{
    \itemize{
      \item The novel internal function \code{frdRanks} was added
      for consistent Friedman-type ranking.
    }
  }
  \subsection{BUGFIXES}{
     \itemize{
       \item Results of all \code{frd[.]Test} and \code{quadeAllPairsTest} depended on the sequential
       order of groups and blocks. This has been fixed.
       Thanks to Jakob Richter, email 2019-10-15.
       \item The function \code{frdManyOneExactTest} was
       corrected towards \sQuote{alternative == "two.sided"} only.
     }

   }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.4.1}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item The function \code{hartleyTest} for performing
      Hartley's Maximum F-Ratio Test of Homogeneity of Variances
      was added.
      }
  }
  \subsection{OTHER CHANGES}{
    \itemize{
      \item The demo trout.R was updated.
    }
  }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.4.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item The function \code{siegelTukeyTest} for
      performing the Siegel-Tukey rank dispersion test
      was added.
      \item The function \code{GSTTest} for
      performing the Generalized Siegel-Tukey Test
      for rank dispersion was added.
    }
  }
  \subsection{BUGFIXES}{
   \itemize{
     \item The names of columns and rows of the lower
     triangle matrix in any of the functions
     \code{frdAllPairs*}, \code{frdManyOne*} and
     \code{quadeAllPairsTest} were occasionally wrong.
     The bug only appeared, if \code{y, group, block}
     were provided as vectors and the group vector was
     sorted. This bug has been fixed.
   }
  }
    \subsection{OTHER CHANGES}{
    \itemize{
      \item Example of Rd file of \code{kruskalTest}
      was modified to show equality of Conover's F and
      one-way ANOVA F-Test with ranks.
    }
  }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.3.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item The function \code{snkTest} for performing
      the Student-Newman-Keuls test was added.
      \item The funtion \code{duncanTest} for performing
      the Duncan's (new) multiple range test was added.
      \item The funtion \code{welchManyOneTTest} for performing
      many-to-one comparisons with Welch's t-test was added.
      Likewise, \code{welchManyOneTTest} was added as \code{test}
      in function \code{powerMCtests}
      \item The funtion \code{steelTest} including
      print and summary S3-methods for applying
      Steel's Many-to-One Rank Test was added.
      \item The function \code{tamhaneT2Test} was extended
      for performing Tamhane's extended T2' test as well. Thanks to
      Sirio Bolaños.
    }
  }
  \subsection{BUGFIXES}{
    \itemize{
      \item Several Rd files were corrected (e.g. links to other man
      files, corrected calls to functions in examples section)
      \item The function \code{tamhaneT2Test} was corrected in order
      to compute the two-tailed p-value with Sidaks p-adjustment using
      \eqn{m = k(k-1)/2}.
    }
  }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.2.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item The function \code{shirleyWilliamsTest} was extended
      for alternatives less and greater using a look-up table
      for critical Williams-t values including
      print and summary methods.
    }
  }
  \subsection{BUGFIXES}{
    \itemize{
      \item Links in Rd file of bwsManyOneTest were corrected.
    }
  }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.1.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item The function \code{williamsTest}
      including print and summary methods were added.
    }
  }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.0.1}{
  \subsection{BUGFIXES}{
    \itemize{
      \item Misspelled author name Terpstra was
      corrected in function \code{jonckheereTest}
      and corresponding Rd file.
      \item Reference in the title of Rd files
      for functions \code{mandelhTest} and \code{mandelkTest}
      were corrected.
    }
  }
}

==> PMCMRplus_1.5.1.tar.gz: PMCMRplus/inst/NEWS.Rd <==
\name{NEWS}
\title{PMCMRplus News}
\encoding{UTF-8}
\section{CHANGES IN PMCMRPLUS VERSION 1.5.1 (2020-09-26)}{
 \subsection{BUGFIX}{
  \itemize{
    \item \code{kwManyOneNdwTest} was corrected for directed hypothesis testing.
  }
 }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.5.0 (2020-09-09)}{
 \subsection{NEW FEATURES}{
  \itemize{
    \item S3 method for class\sQuote{aov} was added
    for \code{tukeyTest}, \code{gamesHowellTest},
    \code{lsdTest}, \code{tamhaneT2Test},
    \code{uryWigginsHochbergTest}, \code{dunnettT3Test},
    \code{snkTest}, \code{scheffeTest}, \code{dunnettTest},
    \code{tamhaneDunnettTest} and \code{welchManyOneTTest}.
    \item Updated concept-tag in Rd files.
  }
 }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.4.4}{
  \subsection{OTHER CHANGES}{
    \itemize{
      \item The examples in \code{kruskalTest}, \code{adKSampleTest}
      and \code{bwsKSampleTest} were
      changed for compatibility with
      the upcoming \sQuote{stringsAsFactors = FALSE} default in R (4.0.0).
      }
    }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.4.3}{
  \subsection{OTHER CHANGES}{
    \itemize{
     \item The names for the \sQuote{method} were corrected for \code{adAllPairsTest} and \code{bwsAllPairsTest}.
     \item The example in \code{adKSampleTest} was corrected.
     }
   }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.4.2}{
 \subsection{NEW FEATURES}{
    \itemize{
      \item The S3 method for class \sQuote{formula} was added
      for \code{frdAllPairsNemenyiTest}.
      }
}
 \subsection{OTHER CHANGES}{
    \itemize{
      \item The novel internal function \code{frdRanks} was added
      for consistent Friedman-type ranking.
    }
  }
  \subsection{BUGFIXES}{
     \itemize{
       \item Results of all \code{frd[.]Test} and \code{quadeAllPairsTest} depended on the sequential
       order of groups and blocks. This has been fixed.
       Thanks to Jakob Richter, email 2019-10-15.
       \item The function \code{frdManyOneExactTest} was
       corrected towards \sQuote{alternative == "two.sided"} only.
     }

   }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.4.1}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item The function \code{hartleyTest} for performing
      Hartley's Maximum F-Ratio Test of Homogeneity of Variances
      was added.
      }
  }
  \subsection{OTHER CHANGES}{
    \itemize{
      \item The demo trout.R was updated.
    }
  }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.4.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item The function \code{siegelTukeyTest} for
      performing the Siegel-Tukey rank dispersion test
      was added.
      \item The function \code{GSTTest} for
      performing the Generalized Siegel-Tukey Test
      for rank dispersion was added.
    }
  }
  \subsection{BUGFIXES}{
   \itemize{
     \item The names of columns and rows of the lower
     triangle matrix in any of the functions
     \code{frdAllPairs*}, \code{frdManyOne*} and
     \code{quadeAllPairsTest} were occasionally wrong.
     The bug only appeared, if \code{y, group, block}
     were provided as vectors and the group vector was
     sorted. This bug has been fixed.
   }
  }
    \subsection{OTHER CHANGES}{
    \itemize{
      \item Example of Rd file of \code{kruskalTest}
      was modified to show equality of Conover's F and
      one-way ANOVA F-Test with ranks.
    }
  }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.3.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item The function \code{snkTest} for performing
      the Student-Newman-Keuls test was added.
      \item The funtion \code{duncanTest} for performing
      the Duncan's (new) multiple range test was added.
      \item The funtion \code{welchManyOneTTest} for performing
      many-to-one comparisons with Welch's t-test was added.
      Likewise, \code{welchManyOneTTest} was added as \code{test}
      in function \code{powerMCtests}
      \item The funtion \code{steelTest} including
      print and summary S3-methods for applying
      Steel's Many-to-One Rank Test was added.
      \item The function \code{tamhaneT2Test} was extended
      for performing Tamhane's extended T2' test as well. Thanks to
      Sirio Bolaños.
    }
  }
  \subsection{BUGFIXES}{
    \itemize{
      \item Several Rd files were corrected (e.g. links to other man
      files, corrected calls to functions in examples section)
      \item The function \code{tamhaneT2Test} was corrected in order
      to compute the two-tailed p-value with Sidaks p-adjustment using
      \eqn{m = k(k-1)/2}.
    }
  }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.2.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item The function \code{shirleyWilliamsTest} was extended
      for alternatives less and greater using a look-up table
      for critical Williams-t values including
      print and summary methods.
    }
  }
  \subsection{BUGFIXES}{
    \itemize{
      \item Links in Rd file of bwsManyOneTest were corrected.
    }
  }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.1.0}{
  \subsection{NEW FEATURES}{
    \itemize{
      \item The function \code{williamsTest}
      including print and summary methods were added.
    }
  }
}
\section{CHANGES IN PMCMRPLUS VERSION 1.0.1}{
  \subsection{BUGFIXES}{
    \itemize{
      \item Misspelled author name Terpstra was
      corrected in function \code{jonckheereTest}
      and corresponding Rd file.
      \item Reference in the title of Rd files
      for functions \code{mandelhTest} and \code{mandelkTest}
      were corrected.
    }
  }
}
